@@ -715,7 +715,7 @@ class QGraphViz_Core(QWidget):
                                 if(os.path.isfile(img_path)):
                                     image = QImage(img_path)
                                 elif(os.path.isfile(img_path2)):
-                                    image = QImage(img_path)
+                                    image = QImage(img_path2)
                         else:
                             img_path = node.kwargs["shape"]
                             img_path2 = os.path.join(os.path.dirname(self.current_path),img_path)
@@ -724,9 +724,14 @@ class QGraphViz_Core(QWidget):
                                 width =  image.size().width()
                                 height =  image.size().height()
                             elif(os.path.isfile(img_path2)):
-                                image = QImage(img_path)
+                                image = QImage(img_path2)
                                 width =  image.size().width()
                                 height =  image.size().height()
+                                if width==0:
+                                    width=100
+                                if height==0:
+                                    height=100
+
                         if image is not None:
                             node.size[0] = width
                             node.size[1] = height
